==> haskell-regex-base-0.94.0.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-base
version:              0.94.0.2
visibility:           public
id:                   regex-base-0.94.0.2-9bnMACbSerDB0WfT2SIplq
key:                  regex-base-0.94.0.2-9bnMACbSerDB0WfT2SIplq
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:
    Herbert Valerio Riedel <hvr@gnu.org>,
    Andreas Abel

author:               Christopher Kuklewicz
homepage:             https://wiki.haskell.org/Regular_expressions
synopsis:             Common "Text.Regex.*" API for Regex matching
description:
    This package does not provide the ability to do regular expression matching.
    Instead, it provides the type classes that constitute the abstract API
    that is implemented by @regex-*@ backends such as:

    * <https://hackage.haskell.org/package/regex-posix regex-posix>

    * <https://hackage.haskell.org/package/regex-parsec regex-parsec>

    * <https://hackage.haskell.org/package/regex-dfa regex-dfa>

    * <https://hackage.haskell.org/package/regex-tdfa regex-tdfa>

    * <https://hackage.haskell.org/package/regex-pcre regex-pcre>

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  7279d16495919b88f036bdae1487753d
exposed:              True
exposed-modules:
    Text.Regex.Base Text.Regex.Base.Context Text.Regex.Base.Impl
    Text.Regex.Base.RegexLike

hidden-modules:       Paths_regex_base
import-dirs:          /usr/lib/ghc-9.0.2/site-local/regex-base-0.94.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/regex-base-0.94.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/regex-base-0.94.0.2
hs-libraries:         HSregex-base-0.94.0.2-9bnMACbSerDB0WfT2SIplq
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-regex-base/html/regex-base.haddock
haddock-html:         /usr/share/doc/haskell-regex-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-base-0.94.0.2-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-base
version:              0.94.0.2
visibility:           public
id:                   regex-base-0.94.0.2-6On48UZuN5IJxnL3aRqiWN
key:                  regex-base-0.94.0.2-6On48UZuN5IJxnL3aRqiWN
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:
    Herbert Valerio Riedel <hvr@gnu.org>,
    Andreas Abel

author:               Christopher Kuklewicz
homepage:             https://wiki.haskell.org/Regular_expressions
synopsis:             Common "Text.Regex.*" API for Regex matching
description:
    This package does not provide the ability to do regular expression matching.
    Instead, it provides the type classes that constitute the abstract API
    that is implemented by @regex-*@ backends such as:

    * <https://hackage.haskell.org/package/regex-posix regex-posix>

    * <https://hackage.haskell.org/package/regex-parsec regex-parsec>

    * <https://hackage.haskell.org/package/regex-dfa regex-dfa>

    * <https://hackage.haskell.org/package/regex-tdfa regex-tdfa>

    * <https://hackage.haskell.org/package/regex-pcre regex-pcre>

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  39b8beb844b14197d4e0f92c693c8151
exposed:              True
exposed-modules:
    Text.Regex.Base Text.Regex.Base.Context Text.Regex.Base.Impl
    Text.Regex.Base.RegexLike

hidden-modules:       Paths_regex_base
import-dirs:          /usr/lib/ghc-9.2.8/site-local/regex-base-0.94.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/regex-base-0.94.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-base
hs-libraries:         HSregex-base-0.94.0.2-6On48UZuN5IJxnL3aRqiWN
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-regex-base/html/regex-base.haddock
haddock-html:         /usr/share/doc/haskell-regex-base/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
